@@ -1,6 +1,7 @@
 import tonic
 import tonic.transforms as transforms
 from utils import create_random_input
+from sys import platform
 
 
 class DummyDataset:
@@ -30,7 +31,7 @@ def test_pytorch_batch_collation_dense_tensor():
     )  # simulate recordings of different length
     batch_size = 2
     dataloader = torch.utils.data.DataLoader(
-        dataset, collate_fn=tonic.collation.PadTensors(), batch_size=batch_size
+        dataset, collate_fn=tonic.collation.PadTensors(batch_first=False), batch_size=batch_size
     )
 
     batch, label = next(iter(dataloader))
@@ -43,5 +44,6 @@ def test_pytorch_batch_collation_dense_tensor():
 
 def test_plotting():
     events, sensor_size = create_random_input()
-
-    tonic.utils.plot_event_grid(events)
+    # this test doesn't finish on Windows
+    if platform == "linux":
+        tonic.utils.plot_event_grid(events)
