@@ -1,10 +1,26 @@
 import pytest
 import numpy as np
 import tonic.transforms as transforms
+import itertools
 from utils import create_random_input
 
 
 class TestTransforms:
+    @pytest.mark.parametrize("min, max", itertools.product((None, 0, 1000), (None, 5000)))
+    def test_crop_time(self, min, max):
+        orig_events, sensor_size = create_random_input()
+
+        transform = transforms.CropTime(min=min, max=max)
+
+        events = transform(orig_events)
+
+        assert events is not orig_events
+        if min is not None:
+            assert not events['t'][0] < min
+        if max is not None:
+            assert not events['t'][-1] > max
+
+
     @pytest.mark.parametrize("filter_time", [10000, 5000])
     def test_transform_denoise(self, filter_time):
         orig_events, sensor_size = create_random_input()
@@ -23,16 +39,11 @@ class TestTransforms:
         )
         assert events is not orig_events
 
-    @pytest.mark.parametrize(
-        "p, random_p", [(0.2, False), (0.5, True)]
-    )
+    @pytest.mark.parametrize("p, random_p", [(0.2, False), (0.5, True)])
     def test_transform_drop_events(self, p, random_p):
         orig_events, sensor_size = create_random_input()
 
-        transform = transforms.DropEvent(
-            p=p,
-            random_p=random_p,
-        )
+        transform = transforms.DropEvent(p=p, random_p=random_p)
 
         events = transform(orig_events)
 
@@ -42,11 +53,8 @@ class TestTransforms:
                 " p*len(original) events dropped out."
             )
         else:
-            assert np.isclose(
-                events.shape[0], (1 - p) * orig_events.shape[0]
-            ), (
-                "Event dropout should result in p*len(original) events"
-                " dropped out."
+            assert np.isclose(events.shape[0], (1 - p) * orig_events.shape[0]), (
+                "Event dropout should result in p*len(original) events" " dropped out."
             )
         assert np.isclose(
             np.sum((events["t"] - np.sort(events["t"])) ** 2), 0
@@ -80,6 +88,29 @@ class TestTransforms:
             assert not np.logical_and(events["x"] == 1, events["y"] == 1).sum()
         assert events is not orig_events
 
+    @pytest.mark.parametrize(
+        "coordinates, hot_pixel_frequency",
+        [(((9, 11), (10, 12), (11, 13)), None), (None, 5000)],
+    )
+    def test_transform_drop_pixel_raster(self, coordinates, hot_pixel_frequency):
+        raster_test = np.random.randint(0, 100, (50, 2, 100, 200))
+        frame_test = np.random.randint(0, 100, (2, 100, 200))
+        transform = transforms.DropPixel(
+            coordinates=coordinates, hot_pixel_frequency=hot_pixel_frequency
+        )
+        raster = transform(raster_test)
+        frame = transform(frame_test)
+
+        if coordinates:
+            for x, y in coordinates:
+                assert raster[:, :, x, y].sum() == 0
+                assert frame[:, x, y].sum() == 0
+        if hot_pixel_frequency:
+            merged_polarity_raster = raster.sum(0).sum(0)
+            merged_polarity_frame = frame.sum(0)
+            assert not merged_polarity_frame[merged_polarity_frame > 5000].sum().sum()
+            assert not merged_polarity_raster[merged_polarity_raster > 5000].sum().sum()
+
     @pytest.mark.parametrize("time_factor, spatial_factor", [(1, 0.25), (1e-3, 1)])
     def test_transform_downsample(self, time_factor, spatial_factor):
         orig_events, sensor_size = create_random_input()
@@ -115,9 +146,7 @@ class TestTransforms:
     def test_transform_flip_lr(self, p):
         orig_events, sensor_size = create_random_input()
 
-        transform = transforms.RandomFlipLR(
-            sensor_size=sensor_size, p=p
-        )
+        transform = transforms.RandomFlipLR(sensor_size=sensor_size, p=p)
 
         events = transform(orig_events)
 
@@ -136,7 +165,29 @@ class TestTransforms:
         events = transform(orig_events)
 
         if p == 1:
-            assert np.array_equal(orig_events["p"] * -1, events["p"]), (
+            assert np.array_equal(np.invert(orig_events["p"].astype(bool)), events["p"]), (
+                "When flipping polarity with probability 1, all event polarities must"
+                " flip"
+            )
+        else:
+            assert np.array_equal(orig_events["p"], events["p"]), (
+                "When flipping polarity with probability 0, no event polarities must"
+                " flip"
+            )
+        assert events is not orig_events
+
+    @pytest.mark.parametrize("p", [1.0, 0])
+    def test_transform_flip_polarity_bools(self, p):
+        orig_events, sensor_size = create_random_input(
+            dtype=np.dtype([("x", int), ("y", int), ("t", int), ("p", bool)])
+        )
+
+        transform = transforms.RandomFlipPolarity(p=p)
+
+        events = transform(orig_events)
+
+        if p == 1:
+            assert np.array_equal(np.invert(orig_events["p"].astype(bool)), events["p"]), (
                 "When flipping polarity with probability 1, all event polarities must"
                 " flip"
             )
@@ -151,9 +202,7 @@ class TestTransforms:
     def test_transform_flip_ud(self, p):
         orig_events, sensor_size = create_random_input()
 
-        transform = transforms.RandomFlipUD(
-            sensor_size=sensor_size, p=p
-        )
+        transform = transforms.RandomFlipUD(sensor_size=sensor_size, p=p)
 
         events = transform(orig_events)
 
