@@ -17,7 +17,7 @@ class PadTensors:
 
     """
 
-    def __init__(self, batch_first: bool = False):
+    def __init__(self, batch_first: bool = True):
         self.batch_first = batch_first
 
     def __call__(self, batch):
@@ -26,17 +26,21 @@ class PadTensors:
 
         max_length = max([sample.shape[0] for sample, target in batch])
         for sample, target in batch:
-            if not isinstance(sample, torch.Tensor): sample = torch.tensor(sample)
-            samples_output.append(
-                torch.cat(
+            if not isinstance(sample, torch.Tensor):
+                sample = torch.tensor(sample)
+            if not isinstance(target, torch.Tensor):
+                target = torch.tensor(target)
+            if sample.is_sparse:
+                sample.sparse_resize_((max_length, *sample.shape[1:]), sample.sparse_dim(), sample.dense_dim())
+            else:
+                sample = torch.cat(
                     (
                         sample,
-                        torch.zeros(max_length - sample.shape[0], *sample.shape[1:]),
-                    )
-                )
-            )
+                        torch.zeros(max_length - sample.shape[0], *sample.shape[1:], device=sample.device),
+                    ))
+            samples_output.append(sample)
             targets_output.append(target)
         return (
             torch.stack(samples_output, 0 if self.batch_first else 1),
-            torch.tensor(targets_output),
+            torch.tensor(targets_output, device=target.device),
         )
