@@ -1,7 +1,7 @@
 from .crop import crop_numpy
 from .denoise import denoise_numpy
 from .drop_event import drop_event_numpy
-from .drop_pixel import drop_pixel_numpy, identify_hot_pixel
+from .drop_pixel import drop_pixel_numpy, identify_hot_pixel, identify_hot_pixel_raster
 from .refractory_period import refractory_period_numpy
 from .slicing import (
     slice_by_time,
@@ -16,6 +16,7 @@ from .to_averaged_timesurface import to_averaged_timesurface
 from .to_frame import to_frame_numpy
 from .to_timesurface import to_timesurface_numpy
 from .to_voxel_grid import to_voxel_grid_numpy
+from .to_bina_rep import to_bina_rep_numpy
 
 __all__ = [
     "crop_numpy",
@@ -31,4 +32,5 @@ __all__ = [
     "to_frame_numpy",
     "to_timesurface_numpy",
     "to_voxel_grid_numpy",
+    "to_bina_rep_numpy",
 ]
