@@ -34,7 +34,7 @@ def to_frame_numpy(
     Returns:
         numpy array with dimensions (TxPxHxW)
     """
-    assert "x" and "y" and "t" and "p" in events.dtype.names
+    assert "x" and "t" and "p" in events.dtype.names
 
     if (
         not sum(
@@ -50,9 +50,16 @@ def to_frame_numpy(
 
     if not sensor_size:
         sensor_size_x = int(events["x"].max() + 1)
-        sensor_size_y = int(events["y"].max() + 1)
         sensor_size_p = len(np.unique(events["p"]))
-        sensor_size = (sensor_size_x, sensor_size_y, sensor_size_p)
+        if "y" in events.dtype.names:
+            sensor_size_y = int(events["y"].max() + 1)
+            sensor_size = (sensor_size_x, sensor_size_y, sensor_size_p)
+        else:
+            sensor_size = (sensor_size_x, 1, sensor_size_p)
+
+    # test for single polarity
+    if sensor_size[2] == 1:
+        events["p"] = 0
 
     if time_window:
         event_slices = slice_by_time(
@@ -67,11 +74,16 @@ def to_frame_numpy(
     elif n_event_bins:
         event_slices = slice_by_event_bins(events, n_event_bins, overlap=overlap)
 
-    frames = np.zeros((len(event_slices), *sensor_size[::-1]), dtype=np.int16)
-    for i, event_slice in enumerate(event_slices):
-        np.add.at(
-            frames,
-            (i, event_slice["p"].astype(int), event_slice["y"], event_slice["x"]),
-            1,
-        )
+    if "y" in events.dtype.names:
+        frames = np.zeros((len(event_slices), *sensor_size[::-1]), dtype=np.int16)
+        for i, event_slice in enumerate(event_slices):
+            np.add.at(
+                frames,
+                (i, event_slice["p"].astype(int), event_slice["y"], event_slice["x"]),
+                1,
+            )
+    else:
+        frames = np.zeros((len(event_slices), sensor_size[2], sensor_size[0]), dtype=np.int16)
+        for i, event_slice in enumerate(event_slices):
+            np.add.at(frames, (i, event_slice["p"].astype(int), event_slice["x"]), 1)
     return frames
