@@ -1,39 +1,43 @@
 import os
 import struct
-import loris
 import numpy as np
 
-events_struct = [("x", np.int16), ("y", np.int16), ("t", np.int64), ("p", bool)]
+
+events_struct = np.dtype([("x", np.int16), ("y", np.int16), ("t", np.int64), ("p", bool)])
 
 # many functions in this file have been copied from https://gitlab.com/synsense/aermanager/-/blob/master/aermanager/parsers.py
-def make_structured_array(x, y, t, p, dtype=events_struct):
+def make_structured_array(*args, dtype=events_struct):
     """
-    Make a structured array given lists of x, y, t, p
+    Make a structured array given a variable number of argument values
 
     Args:
-        x: List of x values
-        y: List of y values
-        t: List of times
-        p: List of polarities boolean
+        *args: Values in the form of nested lists or tuples or numpy arrays. Every except the first argument can be of a primitive data type like int or float
     Returns:
-        xytp: numpy structured array
+        struct_arr: numpy structured array with the shape of the first argument
     """
-    return np.fromiter(zip(x, y, t, p), dtype=dtype)
+    assert not isinstance(args[-1], np.dtype), "The `dtype` must be provided as a keyword argument."
+    names = dtype.names
+    assert len(args) == len(names)
+    struct_arr = np.empty_like(args[0], dtype=dtype)
+    for arg,name in zip(args,names):
+        struct_arr[name] = arg
+    return struct_arr
 
 
 def read_aedat4(in_file):
+    import loris
+
     """
     Get the aer events from version 4 of .aedat file
 
     Args:
         in_file: str The name of the .aedat file
     Returns:
-        shape (Tuple): Shape of the sensor (height, width)
         xytp:   numpy structured array of events
     """
     event_data = loris.read_file(in_file)
     events = event_data["events"]
-    return shape, events
+    return events
 
 
 def read_dvs_128(filename):
@@ -166,7 +170,7 @@ def read_mnist_file(bin_file, dtype):
         all_y[td_indices],
         all_ts[td_indices],
         all_p[td_indices],
-        dtype,
+        dtype=dtype,
     )
     return xytp
 
