@@ -35,6 +35,22 @@ class Compose:
         return format_string
 
 
+@dataclass
+class CropTime:
+    """Drops events with timestamps below min and above max."""
+
+    min: int = None
+    max: int = None
+
+    def __call__(self, events):
+        assert "t" in events.dtype.names
+        if self.min is None:
+            self.min = events["t"][0]
+        if self.max is None:
+            self.max = events["t"][-1]
+        return events[(events["t"] >= self.min) & (events["t"] <= self.max)]
+
+
 @dataclass(frozen=True)
 class Denoise:
     """Drops events that are 'not sufficiently connected to other events in the recording.'
@@ -68,9 +84,7 @@ class DropEvent:
 
     def __call__(self, events):
 
-        return functional.drop_event_numpy(
-            events, self.p, self.random_p
-        )
+        return functional.drop_event_numpy(events, self.p, self.random_p)
 
 
 @dataclass
@@ -85,16 +99,29 @@ class DropPixel:
         hot_pixel_frequency: drop pixels completely that fire higher than the given frequency.
     """
 
-    coordinates: Optional = None
-    hot_pixel_frequency: Optional = None
+    coordinates: Optional[Tuple] = None
+    hot_pixel_frequency: Optional[int] = None
 
     def __call__(self, events):
-        if self.hot_pixel_frequency:
-            self.coordinates = functional.identify_hot_pixel(
-                events=events, hot_pixel_frequency=self.hot_pixel_frequency
+
+        if events.dtype.names is not None:
+            # assert "x", "y", "p" in events.dtype.names
+            if self.hot_pixel_frequency:
+                self.coordinates = functional.identify_hot_pixel(
+                    events=events, hot_pixel_frequency=self.hot_pixel_frequency
+                )
+
+            return functional.drop_pixel_numpy(
+                events=events, coordinates=self.coordinates
             )
 
-        return functional.drop_pixel_numpy(events=events, coordinates=self.coordinates)
+        elif len(events.shape) == 4 or len(events.shape) == 3:
+            if self.hot_pixel_frequency:
+                self.coordinates = functional.identify_hot_pixel_raster(
+                    events=events, hot_pixel_frequency=self.hot_pixel_frequency
+                )
+
+            return functional.drop_pixel.drop_pixel_raster(events, self.coordinates)
 
 
 @dataclass(frozen=True)
@@ -109,7 +136,7 @@ class Downsample:
         spatial_factor (float): value to multiply pixel coordinates with. Default is 1.
     """
 
-    time_factor: float = 1e-3
+    time_factor: float = 1
     spatial_factor: float = 1
 
     def __call__(self, events):
@@ -197,10 +224,8 @@ class RandomFlipPolarity:
     def __call__(self, events):
         events = events.copy()
         assert "p" in events.dtype.names
-        flips = np.ones(len(events))
-        probs = np.random.rand(len(events))
-        flips[probs < self.p] = -1
-        events["p"] = events["p"] * flips
+        if np.random.rand() <= self.p:
+            events["p"] = np.invert(events["p"].astype(bool)).astype(events.dtype["p"])
         return events
 
 
@@ -429,6 +454,7 @@ class ToAveragedTimesurface:
         temporal_window (float): how far back to look for past events for the time averaging
         tau (float): time constant to decay events around occuring event with.
         decay (str): can be either 'lin' or 'exp', corresponding to linear or exponential decay.
+        num_workers (int): number of workers to be deployed on the histograms computation. When >1, joblib is required.
     """
 
     sensor_size: Tuple[int, int, int]
@@ -437,9 +463,9 @@ class ToAveragedTimesurface:
     temporal_window: int = 5e5
     tau: int = 5e3
     decay: str = "lin"
+    num_workers: int = 1
 
     def __call__(self, events):
-
         return functional.to_averaged_timesurface(
             events,
             sensor_size=self.sensor_size,
@@ -448,6 +474,7 @@ class ToAveragedTimesurface:
             temporal_window=self.temporal_window,
             tau=self.tau,
             decay=self.decay,
+            num_workers=self.num_workers,
         )
 
 
@@ -455,6 +482,7 @@ class ToAveragedTimesurface:
 class ToFrame:
     """Accumulate events to frames by slicing along constant time (time_window),
     constant number of events (spike_count) or constant number of frames (n_time_bins / n_event_bins).
+    All the events in one slice are added up in a frame for each polarity.
     You can set one of the first 4 parameters to choose the slicing method. Depending on which method you choose,
     overlap will assume different functionality, whether that might be temporal overlap, number of events
     or fraction of a bin. As a rule of thumb, here are some considerations if you are unsure which slicing
@@ -511,6 +539,61 @@ class ToFrame:
         )
 
 
+@dataclass(frozen=True)
+class ToSparseTensor:
+    """
+    Sparse tensor PyTorch drop-in replacement for ToFrame. See https://pytorch.org/docs/stable/sparse.html for details
+    about sparse tensors. A sparse tensor will use the events as indices in the order (tpxy) and values
+    of 1 for each index, which signify a spike. The shape of the tensor will be (TCWH).
+    Turn event array (N,E) into sparse Tensor (B,T,H,W) if E is 4 (mostly event camera recordings),
+    otherwise into sparse tensor (B,T,H) mostly for audio recordings.
+    """
+
+    sensor_size: Tuple[int, int, int]
+    time_window: Optional[float] = None
+    event_count: Optional[int] = None
+    n_time_bins: Optional[int] = None
+    n_event_bins: Optional[int] = None
+    overlap: float = 0
+    include_incomplete: bool = False
+
+    def __call__(self, events):
+        try:
+            import torch
+        except ImportError:
+            raise ImportError("PyTorch not installed.")
+
+        dense_frames = functional.to_frame_numpy(
+            events=events,
+            sensor_size=self.sensor_size,
+            time_window=self.time_window,
+            event_count=self.event_count,
+            n_time_bins=self.n_time_bins,
+            n_event_bins=self.n_event_bins,
+            overlap=self.overlap,
+            include_incomplete=self.include_incomplete,
+        )
+        return torch.from_numpy(dense_frames).to_sparse()
+
+
+@dataclass(frozen=True)
+class ToImage:
+    """Counts up all events to a *single* image of size sensor_size. ToImage will typically
+    be used in combination with SlicedDataset to cut a recording into smaller chunks that
+    are then individually binned to frames.
+    """
+
+    sensor_size: Tuple[int, int, int]
+
+    def __call__(self, events):
+
+        frames = functional.to_frame_numpy(
+            events=events, sensor_size=self.sensor_size, event_count=len(events)
+        )
+
+        return frames.squeeze(0)
+
+
 @dataclass(frozen=True)
 class ToTimesurface:
     """Representation that creates timesurfaces for each event in the recording. Modeled after the paper
@@ -560,6 +643,43 @@ class ToVoxelGrid:
         )
 
 
+@dataclass(frozen=True)
+class ToBinaRep:
+    """Representation that takes T*B binary event frames to produce a sequence of T frames of N-bit numbers.
+    To do so, N binary frames are interpreted as a single frame of N-bit representation. Taken from the paper
+    Barchid et al. 2022, Bina-Rep Event Frames: a Simple and Effective Representation for Event-based cameras
+    https://arxiv.org/pdf/2202.13662.pdf
+
+    Parameters:
+        n_frames (int): the number T of bina-rep frames.
+        n_bits (int): the number N of bits used in the N-bit representation.
+
+
+    Example:
+        >>> n_time_bins = n_frames * n_bits
+        >>>
+        >>> transforms.Compose([
+        >>>     transforms.ToFrame(
+        >>>         sensor_size=sensor_size,
+        >>>         n_time_bins=n_time_bins,
+        >>>     ),
+        >>>     transforms.ToBinaRep(
+        >>>         n_frames=n_frames,
+        >>>         n_bits=n_bits,
+        >>>     ),
+        >>> ])
+    """
+
+    n_frames: Optional[int] = 1
+    n_bits: Optional[int] = 8
+
+    def __call__(self, event_frames):
+
+        return functional.to_bina_rep_numpy(
+            event_frames, self.n_frames, self.n_bits
+        )
+
+
 @dataclass(frozen=True)
 class Repeat:
     """Copies target n times. Useful to transform sample labels into sequences."""
